Struct that represents a combination of expressions that all must be true.
An AllOf without children evaluates to true.
Summary
Types
@type t() :: %LetMe.AllOf{children: [LetMe.expression()], passed?: boolean() | nil}
Struct that represents a combination of expressions that all must be true.
An AllOf without children evaluates to true.
@type t() :: %LetMe.AllOf{children: [LetMe.expression()], passed?: boolean() | nil}