Struct that represents a combination of checks one of which must be true.
An AnyOf without children evaluates to false.
Summary
Types
@type t() :: %LetMe.AnyOf{children: [LetMe.expression()], passed?: boolean() | nil}
Struct that represents a combination of checks one of which must be true.
An AnyOf without children evaluates to false.
@type t() :: %LetMe.AnyOf{children: [LetMe.expression()], passed?: boolean() | nil}