Struct that represents an authorization rule that evaluates to a fixed value.
Summary
Types
@type t() :: %LetMe.Literal{passed?: boolean()}
Struct that represents an authorization rule that evaluates to a fixed value.
@type t() :: %LetMe.Literal{passed?: boolean()}